@@ -25,6 +25,8 @@ from bl_ui.space_view3d import (
     VIEW3D_PT_shading_options,
 )
 
+from bl_ui.properties_grease_pencil_common import GreasePencilSimplifyPanel
+
 
 class RenderButtonsPanel:
     bl_space_type = 'PROPERTIES'
@@ -171,8 +173,12 @@ class RENDER_PT_eevee_motion_blur(RenderButtonsPanel, Panel):
 
         layout.active = props.use_motion_blur
         col = layout.column()
-        col.prop(props, "motion_blur_samples")
+        col.prop(props, "motion_blur_position", text="Position")
         col.prop(props, "motion_blur_shutter")
+        col.separator()
+        col.prop(props, "motion_blur_depth_scale")
+        col.prop(props, "motion_blur_max")
+        col.prop(props, "motion_blur_steps", text="Steps")
 
 
 class RENDER_PT_eevee_depth_of_field(RenderButtonsPanel, Panel):
@@ -292,7 +298,7 @@ class RENDER_PT_eevee_volumetric_shadows(RenderButtonsPanel, Panel):
         props = scene.eevee
 
         layout.active = props.use_volumetric_shadows
-        layout.prop(props, "volumetric_shadow_samples", text="Shadow Samples")
+        layout.prop(props, "volumetric_shadow_samples", text="Samples")
 
 
 class RENDER_PT_eevee_subsurface_scattering(RenderButtonsPanel, Panel):
@@ -314,7 +320,6 @@ class RENDER_PT_eevee_subsurface_scattering(RenderButtonsPanel, Panel):
         col = layout.column()
         col.prop(props, "sss_samples")
         col.prop(props, "sss_jitter_threshold")
-        col.prop(props, "use_sss_separate_albedo")
 
 
 class RENDER_PT_eevee_screen_space_reflections(RenderButtonsPanel, Panel):
@@ -366,7 +371,6 @@ class RENDER_PT_eevee_shadows(RenderButtonsPanel, Panel):
         props = scene.eevee
 
         col = layout.column()
-        col.prop(props, "shadow_method")
         col.prop(props, "shadow_cube_size", text="Cube Size")
         col.prop(props, "shadow_cascade_size", text="Cascade Size")
         col.prop(props, "use_shadow_high_bitdepth")
@@ -475,33 +479,21 @@ class RENDER_PT_eevee_film(RenderButtonsPanel, Panel):
 
         scene = context.scene
         rd = scene.render
+        props = scene.eevee
 
         col = layout.column()
         col.prop(rd, "filter_size")
         col.prop(rd, "film_transparent", text="Transparent")
 
-
-class RENDER_PT_eevee_film_overscan(RenderButtonsPanel, Panel):
-    bl_label = "Overscan"
-    bl_parent_id = "RENDER_PT_eevee_film"
-    bl_options = {'DEFAULT_CLOSED'}
-    COMPAT_ENGINES = {'BLENDER_EEVEE'}
-
-    def draw_header(self, context):
-
-        scene = context.scene
-        props = scene.eevee
-
-        self.layout.prop(props, "use_overscan", text="")
-
-    def draw(self, context):
-        layout = self.layout
-        layout.use_property_split = True
-        scene = context.scene
-        props = scene.eevee
-
-        layout.active = props.use_overscan
-        layout.prop(props, "overscan_size", text="Size")
+        col = layout.column(align=False, heading="Overscan")
+        col.use_property_decorate = False
+        row = col.row(align=True)
+        sub = row.row(align=True)
+        sub.prop(props, "use_overscan", text="")
+        sub = sub.row(align=True)
+        sub.active = props.use_overscan
+        sub.prop(props, "overscan_size", text="")
+        row.prop_decorator(props, "overscan_size")
 
 
 class RENDER_PT_eevee_hair(RenderButtonsPanel, Panel):
@@ -524,6 +516,43 @@ class RENDER_PT_eevee_hair(RenderButtonsPanel, Panel):
         layout.prop(rd, "hair_subdiv")
 
 
+class RENDER_PT_eevee_performance(RenderButtonsPanel, Panel):
+    bl_label = "Performance"
+    bl_options = {'DEFAULT_CLOSED'}
+    COMPAT_ENGINES = {'BLENDER_EEVEE', 'BLENDER_WORKBENCH'}
+
+    @classmethod
+    def poll(cls, context):
+        return (context.engine in cls.COMPAT_ENGINES)
+
+    def draw(self, context):
+        layout = self.layout
+        scene = context.scene
+        rd = scene.render
+
+        layout.use_property_split = True
+
+        layout.prop(rd, "use_high_quality_normals")
+
+
+class RENDER_PT_gpencil(RenderButtonsPanel, Panel):
+    bl_label = "Grease Pencil"
+    bl_options = {'DEFAULT_CLOSED'}
+    bl_order = 10
+    COMPAT_ENGINES = {'BLENDER_RENDER', 'BLENDER_EEVEE', 'BLENDER_WORKBENCH'}
+
+    def draw(self, context):
+        layout = self.layout
+        layout.use_property_split = True
+        layout.use_property_decorate = False  # No animation.
+
+        scene = context.scene
+        props = scene.grease_pencil_settings
+
+        col = layout.column()
+        col.prop(props, "antialias_threshold")
+
+
 class RENDER_PT_opengl_sampling(RenderButtonsPanel, Panel):
     bl_label = "Sampling"
     COMPAT_ENGINES = {'BLENDER_WORKBENCH'}
@@ -542,7 +571,7 @@ class RENDER_PT_opengl_sampling(RenderButtonsPanel, Panel):
 
         col = layout.column()
         col.prop(props, "render_aa", text="Render")
-        col.prop(props, "viewport_aa", text="Viewport Render")
+        col.prop(props, "viewport_aa", text="Viewport")
 
 
 class RENDER_PT_opengl_film(RenderButtonsPanel, Panel):
@@ -630,7 +659,7 @@ class RENDER_PT_simplify_viewport(RenderButtonsPanel, Panel):
         col.prop(rd, "simplify_child_particles", text="Max Child Particles")
 
         col = flow.column()
-        col.prop(rd, "use_simplify_smoke_highres", text="High-resolution Smoke")
+        col.prop(rd, "simplify_volumes", text="Volume Resolution")
 
 
 class RENDER_PT_simplify_render(RenderButtonsPanel, Panel):
@@ -655,36 +684,12 @@ class RENDER_PT_simplify_render(RenderButtonsPanel, Panel):
         col.prop(rd, "simplify_child_particles_render", text="Max Child Particles")
 
 
-class RENDER_PT_simplify_greasepencil(RenderButtonsPanel, Panel):
+class RENDER_PT_simplify_greasepencil(RenderButtonsPanel, Panel, GreasePencilSimplifyPanel):
     bl_label = "Grease Pencil"
     bl_parent_id = "RENDER_PT_simplify"
-    COMPAT_ENGINES = {'BLENDER_RENDER', 'BLENDER_GAME', 'BLENDER_CLAY', 'BLENDER_EEVEE'}
+    COMPAT_ENGINES = {'BLENDER_RENDER', 'BLENDER_GAME', 'BLENDER_CLAY', 'BLENDER_EEVEE', 'BLENDER_WORKBENCH'}
     bl_options = {'DEFAULT_CLOSED'}
 
-    def draw_header(self, context):
-        rd = context.scene.render
-        self.layout.prop(rd, "simplify_gpencil", text="")
-
-    def draw(self, context):
-        layout = self.layout
-        layout.use_property_split = True
-        layout.use_property_decorate = False
-
-        rd = context.scene.render
-
-        layout.active = rd.simplify_gpencil
-
-        col = layout.column()
-        col.prop(rd, "simplify_gpencil_onplay", text="Playback Only")
-        col.prop(rd, "simplify_gpencil_view_modifier", text="Modifiers")
-        col.prop(rd, "simplify_gpencil_shader_fx", text="ShaderFX")
-        col.prop(rd, "simplify_gpencil_blend", text="Layers Blending")
-
-        col.prop(rd, "simplify_gpencil_view_fill")
-        sub = col.column()
-        sub.active = rd.simplify_gpencil_view_fill
-        sub.prop(rd, "simplify_gpencil_remove_lines", text="Lines")
-
 
 classes = (
     RENDER_PT_context,
@@ -698,12 +703,14 @@ classes = (
     RENDER_PT_eevee_volumetric,
     RENDER_PT_eevee_volumetric_lighting,
     RENDER_PT_eevee_volumetric_shadows,
+    RENDER_PT_eevee_performance,
     RENDER_PT_eevee_hair,
     RENDER_PT_eevee_shadows,
     RENDER_PT_eevee_indirect_lighting,
     RENDER_PT_eevee_indirect_lighting_display,
     RENDER_PT_eevee_film,
-    RENDER_PT_eevee_film_overscan,
+
+    RENDER_PT_gpencil,
     RENDER_PT_opengl_sampling,
     RENDER_PT_opengl_lighting,
     RENDER_PT_opengl_color,
